==> haskell-call-stack-0.2.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-call-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 call-stack
version:              0.2.0
visibility:           public
id:                   call-stack-0.2.0-GaSR7xpoHcKCc3B0wbLwvx
key:                  call-stack-0.2.0-GaSR7xpoHcKCc3B0wbLwvx
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/call-stack#readme
synopsis:             Use GHC call-stacks in a backward compatible way
category:             Data
abi:                  77778660a10f6d919dbb1d10be41cac0
exposed:              True
exposed-modules:      Data.CallStack
hidden-modules:       Data.SrcLoc Paths_call_stack
import-dirs:          /usr/lib/ghc-8.10.2/site-local/call-stack-0.2.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/call-stack-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/call-stack-0.2.0
hs-libraries:         HScall-stack-0.2.0-GaSR7xpoHcKCc3B0wbLwvx
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-call-stack/html/call-stack.haddock
haddock-html:         /usr/share/doc/haskell-call-stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-call-stack-0.2.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-call-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 call-stack
version:              0.2.0
visibility:           public
id:                   call-stack-0.2.0-B1VMUrTk40PIqOUP3CZorq
key:                  call-stack-0.2.0-B1VMUrTk40PIqOUP3CZorq
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/call-stack#readme
synopsis:             Use GHC call-stacks in a backward compatible way
category:             Data
abi:                  94054cd69bad39160d3f6399df4c774c
exposed:              True
exposed-modules:      Data.CallStack
hidden-modules:       Data.SrcLoc Paths_call_stack
import-dirs:          /usr/lib/ghc-8.10.2/site-local/call-stack-0.2.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/call-stack-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/call-stack-0.2.0
hs-libraries:         HScall-stack-0.2.0-B1VMUrTk40PIqOUP3CZorq
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-call-stack/html/call-stack.haddock
haddock-html:         /usr/share/doc/haskell-call-stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
